﻿* Encoding: UTF-8.
**DATA PREPARATION 
Towards a Conceptualisation of Intensive Parenting Norms: Testing Exact and Approximate Measurement Invariance across Social and Country Contexts
************************************************************************************************
 * DATA CLEANING CRONOS DATA W2.
************************************************************************************************
* 1) Download CRONOS0-6ESSintegratedfile, edition 1.2 from https://www.europeansocialsurvey.org/data/download_cronos.html.
cd "H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021" .
GET 
  FILE='H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021\CRONOS_ESS8_e01_2_all.sav'.
dataset name CRONOSall window=front.
* 2) Select only respondents of second wawe of Cronos.  N=1828.
recode w2weight (missing = 0 ) (else =1) into wave2. 
fre wave2.
DATASET ACTIVATE DataSet1.
USE ALL.
COMPUTE filter_$=(wave2 = 1).
VARIABLE LABELS filter_$ 'wave2 = 1 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

SAVE OUTFILE='H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021\ESS_Cronos_W2.sav'
  /COMPRESSED.


*3) DATA PREPARATION: PARENTING NORMS ITEMS 
*In order to make sure that a high score on the item means a high support on intensive parenting, 
11 items on 18 were reversed coded to capture the opposite of intensive parenting, in line with Gauthier et al. 2021. 
*Original response scale: 1 strongly agree - 5 strongly disagree. 
compute q55=  6- w2q55.
compute q56=  6- w2q56.
compute q57=w2q57.
compute q58=  6- w2q58.
compute q59=w2q59.
compute q60=w2q60.
compute q61=  6- w2q61.
compute q62=w2q62.
compute q63=  6- w2q63.
compute q64=w2q64.
compute q65=  6- w2q65.
compute q66=  6- w2q66.
compute q67=  6- w2q67.
compute q68=  6- w2q68.
compute q69=  6- w2q69.
compute q70=w2q70.
compute q71=w2q71.
compute q72=  6- w2q72.
EXECUTE.
*higher value = higher support to itensive parenting norm.
value labels q55 to q72 5 "Strongly agree" 4 "Agree" 3 "Neither agree nor disagree" 2 "Disagree" 1 "Strongly disagree".
var lab  q55 "ChNeeds (reverse)".
var lab q56 "AdviceProf (reverse) ".
var lab  q57 "LessAvailable".
var lab q58 "ChSuccess (reverse)".
var lab q59 "FamRoutine".
var lab q60 "BadJob".
var lab q61 "AlwaysAvailable(reverse)".
var lab q62 "ChMistakes".
var lab q63 "ChAttention (reverse)".
var lab q64 "PaKnow".
var lab q65 "Activities (reverse)".
var lab q66  "PaWorry(reverse)".
var lab q67 "ChTalents (reverse)".
var lab q68 "AwareExperts (reverse)".
var lab q69 "BasicNeeds (reverse)".
var lab q70 "PaLife".
var lab q71 "LatestToys".
var lab q72 "PaStress (reverse)".

**check for missings, items intensive parenting scale, by country.
DATASET ACTIVATE ESS_Cronos_wave2.
SORT CASES  BY country.
SPLIT FILE LAYERED BY country.
fre  q55 to q72.

* 4) DATA PREPARATION:  SOCIO-DEMOGRAPHIC VARIABLES.
fre  gndr.
recode cntry ("EE"=1) ("GB"=2) ("SI"=3) into country.
val lab country 1 "Estonia" 2 "Great Britain" 3 "Slovenia". 
****EDUCATION - 3 CATEGORIES.
fre eisced.
recode eisced (1 thru 2=1) (3 thru 4=2) (5 thru 7=3)  into edu.

VALUE LABELS edu 1 "low" 2 "medium" 3"high".
variable labels edu "educational level".
fre edu.

***parental status. 
fre chldhm chldhhe.
recode chldhm (1=1) (2=0) into parent.
exe.
recode chldhhe (1=1) into parent.
exe.
VARIABLE LABELS parent "ever have child".
fre parent.

****having child under 12 .
*compute age of household members .
fre inwyys.
do if   inwyye=2016.
compute age1= 2016-yrbrn2.
compute age2= 2016-yrbrn3.
compute age3= 2016-yrbrn4.
compute age4= 2016-yrbrn5.
compute age5= 2016-yrbrn6.
compute age6= 2016-yrbrn7.
compute age7= 2016-yrbrn8.
compute age8= 2016-yrbrn9.
compute age9= 2016-yrbrn10.
compute age10= 2016-yrbrn11.
end if. 
exe.
do if   inwyye=2017.
compute age1= 2017-yrbrn2.
compute age2= 2017-yrbrn3.
compute age3= 2017-yrbrn4.
compute age4= 2017-yrbrn5.
compute age5= 2017-yrbrn6.
compute age6= 2017-yrbrn7.
compute age7= 2017-yrbrn8.
compute age8= 2017-yrbrn9.
compute age9= 2017-yrbrn10.
compute age10= 2017-yrbrn11.
end if. 
exe.
***having child under housedhold and aged =< 12 .
fre chldhm.
IF  (chldhm = 2) child12=0.
EXECUTE.
do if  chldhm = 1.
COUNT child12=age1 to age10 (0 thru 12).
end if.
EXECUTE.
VARIABLE LABELS child12 'having child under 12 years'.
recode child12 (1 thru highest=1) (0=0).
exe.
value labels child12  1"yes" 0 "no".

fre child12.
CROSSTABS child12 by parent.

***having child 3 categoies.
compute child_3_cat=parent.
do if child12=0.
recode  child_3_cat (1=2).
end if.
exe. 
VALUE LABELS child_3_cat  0 "no child" 1 "child under 12" 2 "older".

fre parent child12 child_3_cat.

 * 5) DESCRIPTIVES. / 14 missing cases for education 
DATASET ACTIVATE DataSet3.
WEIGHT BY w2weight.

fre gndr edu parent child12.


 * 6) SAVE FINAL ANALYTICAL SAMPLE/ DROPPING MISSING CASES
*Final analytical sample - 14 items. N=1713.
DATASET COPY  final.
DATASET ACTIVATE  final.
FILTER OFF.
USE ALL.
SELECT IF (NMISS(edu,q55, q56, q57, q60, q61, q63, q64, q65, q66, q67, q68, q69, q70, q71) <1 ).
EXECUTE.
DATASET ACTIVATE  DataSet1.

.
**FINAL SAVE. 

DATASET ACTIVATE  final.
SAVE OUTFILE='H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021\ESS_Cronos_W2_14items.sav'
   /KEEP=country idno gndr q55 to q71 edu parent child12 w2weight  
  /COMPRESSED.


*save as STATA file. 
SAVE TRANSLATE OUTFILE= 
    'H:\Jana\PROJEKTY\pracovni2023\GACR\revize_invariance\replication\ESS_Cronos_W2_14items.dta' 
  /TYPE=STATA 
  /VERSION=13 
  /EDITION=SE 
  /MAP 
  /REPLACE.

*data file 7 items.q59 q63 q65 q66 q67 q69 q70.

fre q59 q63 q65 q66 q67 q69 q70.
SAVE OUTFILE='H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021\ESS_Cronos_W2_7items.sav'
   /KEEP=country idno gndr q59 q63 q65 q66 q67 q69 q70 edu parent child12 w2weight  
  /COMPRESSED.
.
USE ALL.
SELECT IF (NMISS(edu, q59, q63, q65, q66, q67, q69, q70) <1 ).
EXECUTE.
SAVE OUTFILE='H:\Jana\PROJEKTY\pracovni2022\GACR\Kristyna\Replikace_analyz_Gauthier2021\ESS_Cronos_W2_7items.sav'
   /KEEP=country idno gndr q55 to q71 edu parent child12 w2weight  
  /COMPRESSED.


*for analysis in MPLUS save separate files as .dat. 

 * 7) Descriptives (Table 2 in paper) - ESS_Cronos_W2_14items.sav  *

WEIGHT BY w2weight.
SORT CASES  BY country.
SPLIT FILE LAYERED BY country.
FREQUENCIES gndr edu parent child12.


DATASET ACTIVATE DataSet2.
SPLIT FILE OFF.
fre country gndr edu parent child12.
fre country .

***********************************************
**additional analysess missing info on parenting norms by socio-dem. groups. data: ESS_Cronos_W2.

USE ALL.
COMPUTE mis14=(NMISS(q55, q56, q57, q60, q61, q63, q64, q65, q66, q67, q68, q69, q70, q71)).
exe.
recode mis14 (1 thru highest =1).
exe.

USE ALL.
COMPUTE mis7=(NMISS(q59, q63, q65, q66, q67, q69, q70)).
exe.
recode mis7(1 thru highest =1).
exe.
fre mis7.

WEIGHT BY w2weight.
fre mis14.

CROSSTABS
  /TABLES=mis14 BY country
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY edu
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY parent
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY child12
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY gndr
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

crosstabs mis14 by country.
SORT CASES  BY mis14.
SPLIT FILE LAYERED BY mis14.
fre country gndr edu parent child12.


SORT CASES  BY country.
SPLIT FILE LAYERED BY country.

CROSSTABS
  /TABLES=mis14 BY gndr
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY edu
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.


CROSSTABS
  /TABLES=mis14 BY parent
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

CROSSTABS
  /TABLES=mis14 BY child12
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.










